@@ -4,7 +4,7 @@ Lager CLI
 A Command Line Interface for Lager Data
 """
 
-__version__ = '0.1.70'
+__version__ = '0.1.95'
 
 SUPPORTED_DEVICES = (
     'at91samdexx',
@@ -36,8 +36,12 @@ SUPPORTED_DEVICES = (
     'stm32wbx',
     'stm32wlx',
     'stm32xl',
-    'imxrx1050',
-    'imxrx1064',
+    'imxrt1050',
+    'imxrt1064',
+    'MIMXRT1064xxx5A',
+    'MIMXRT1064xxx6A',
+    'lpc54xx',
+    'lpc55xx',
 )  # Empty docstring below is to suppress tuple docstring that would otherwise be printed by autodoc
 """
 """
