@@ -15,11 +15,13 @@ from .context import LagerContext
 
 from .gateway.commands import _gateway
 from .adc.commands import adc
+from .ble.commands import ble
 from .setter.commands import setter
 from .lister.commands import lister
 from .auth import load_auth
 from .auth.commands import login, logout
 from .canbus.commands import canbus
+from .chip_erase.commands import chip_erase
 from .job.commands import job
 from .devenv.commands import devenv
 from .exec.commands import exec_
@@ -37,6 +39,10 @@ from .python.commands import python
 from .wifi.commands import _wifi
 from .serial_ports.commands import serial_ports
 from .webcam.commands import webcam
+from .grafana.commands import grafana
+from .pigpio.commands import pigpio
+from .spi.commands import spi
+from .i2c.commands import i2c
 from .util import check_version
 
 def _decode_environment():
@@ -72,11 +78,13 @@ def cli(ctx=None, see_version=None, debug=False, colorize=False, version_check=T
 
 cli.add_command(_gateway)
 cli.add_command(adc)
+cli.add_command(ble)
 cli.add_command(setter)
 cli.add_command(lister)
 cli.add_command(login)
 cli.add_command(logout)
 cli.add_command(canbus)
+cli.add_command(chip_erase)
 cli.add_command(job)
 cli.add_command(devenv)
 cli.add_command(exec_)
@@ -95,6 +103,10 @@ cli.add_command(python)
 cli.add_command(_wifi)
 cli.add_command(serial_ports)
 cli.add_command(webcam)
+cli.add_command(grafana)
+cli.add_command(pigpio)
+cli.add_command(spi)
+cli.add_command(i2c)
 
 def setup_context(ctx, debug, colorize, skip_auth):
     """
