@@ -22,6 +22,7 @@ from .exceptions import GatewayTimeoutError
 
 _DEFAULT_HOST = 'https://app.lagerdata.com'
 _DEFAULT_WEBSOCKET_HOST = 'wss://app.lagerdata.com'
+DEFAULT_REGION = 'us-west-1'
 
 def print_openocd_error(error):
     """
@@ -98,6 +99,8 @@ class LagerSession(BaseUrlSession):
         except RuntimeError:
             pass
         if r.status_code == 404:
+            if '/api/v1/gateway/1/download-file' in r.request.path_url:
+                r.raise_for_status()
             name = ctx.params['gateway'] or ctx.obj.default_gateway
             click.secho('You don\'t have a gateway with id `{}`'.format(name), fg='red', err=True)
             click.secho(
@@ -158,6 +161,17 @@ class LagerSession(BaseUrlSession):
         if response_hook:
             self.hooks['response'].append(response_hook)
 
+    def should_strip_auth(self, old_url, new_url):
+        """
+            Decide whether Authorization header should be removed when redirecting, allowing for
+            forwarding auth to region-specific lager servers
+        """
+        old = urllib.parse.urlparse(old_url)
+        new = urllib.parse.urlparse(new_url)
+        if old.hostname.endswith('.lagerdata.com') and new.hostname.endswith('.lagerdata.com'):
+            return False
+
+        return super().should_strip_auth(old_url, new_url)
 
     def request(self, *args, **kwargs):
         """
@@ -177,6 +191,19 @@ class LagerSession(BaseUrlSession):
             click.secho('Could not connect to Lager API', fg='red', err=True)
             click.get_current_context().exit(1)
 
+    def chip_erase(self, gateway, device, interface, transport, speed):
+        """
+            Chip-erase the DUT
+        """
+        url = 'gateway/{}/chip-erase'.format(quote(gateway))
+        data = {
+            'device': device,
+            'interface': interface,
+            'transport': transport,
+            'speed': speed,
+        }
+        return self.post(url, json=data)
+
     def start_debugger(self, gateway, files):
         """
             Start the debugger on the gateway
@@ -317,6 +344,13 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/gpio/output'.format(quote(gateway))
         return self.post(url, json={'gpio': gpio, 'level': level})
 
+    def gpio_power(self, gateway, bus, level):
+        """
+            Set a bus enable pin to high or low
+        """
+        url = 'gateway/{}/gpio/power'.format(quote(gateway))
+        return self.post(url, json={'bus': bus, 'level': level})
+
     def gpio_servo(self, gateway, gpio, pulsewidth, stop):
         """
             Control a servo with GPIO
@@ -364,14 +398,14 @@ class LagerSession(BaseUrlSession):
             Connect the gateway to a wifi network
         """
         url = 'gateway/{}/wifi/connect'.format(quote(gateway))
-        return self.post(url, json={'ssid': ssid, 'password': password, 'iface': interface})
+        return self.post(url, json={'ssid': ssid, 'password': password, 'interface': interface})
 
     def delete_wifi_connection(self, gateway, ssid, interface):
         """
             Delete the wifi connection for the specified gateway
         """
         url = 'gateway/{}/wifi/delete-connection'.format(quote(gateway))
-        return self.post(url, json={'ssid': ssid, 'iface': interface})
+        return self.post(url, json={'ssid': ssid, 'interface': interface})
 
     def can_up(self, gateway, bitrate, interfaces):
         """
@@ -435,6 +469,30 @@ class LagerSession(BaseUrlSession):
         url = 'gateway/{}/poweroff'.format(quote(gateway))
         return self.post(url)
 
+    def ble_scan(self, gateway, timeout):
+        """
+            scan for BLE devices
+        """
+        url = 'gateway/{}/ble/scan'.format(quote(gateway))
+        return self.get(url, params={'timeout': timeout})
+
+    def download_file(self, gateway, filename):
+        """
+            download a file from gateway
+        """
+        url = 'gateway/{}/download-file'.format(quote(gateway))
+        return self.get(url, params={'filename': filename}, stream=True)
+
+    def region(self, gateway):
+        """
+            get the region for the gateway
+        """
+        url = 'gateway/{}/region'.format(quote(gateway))
+        region = self.get(url).json()['region']
+        if region == DEFAULT_REGION:
+            return None
+        return region
+
 class LagerContext:  # pylint: disable=too-few-public-methods
     """
         Lager Context manager
@@ -443,6 +501,7 @@ class LagerContext:  # pylint: disable=too-few-public-methods
         ws_host = os.getenv('LAGER_WS_HOST', _DEFAULT_WEBSOCKET_HOST)
         response_hook = functools.partial(LagerSession.handle_errors, ctx)
         self.session = LagerSession(auth, response_hook=response_hook)
+        self.session.max_redirects = 2
         self.defaults = defaults
         self.style = style
         self.ws_host = ws_host
@@ -477,9 +536,18 @@ class LagerContext:  # pylint: disable=too-few-public-methods
             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/8081'
         elif socktype == 'pdb':
             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/5555'
+        elif socktype == 'pigpio-tunnel':
+             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/8888'
+        elif socktype == 'grafana-tunnel':
+             path = f'/ws/gateway/{kwargs["gateway_id"]}/gdb-tunnel/3000'
         else:
             raise ValueError(f'Invalid websocket type: {socktype}')
-        uri = urllib.parse.urljoin(self.ws_host, path)
+
+        if kwargs.get('region') and 'dev.lagerdata.app' not in self.ws_host:
+            ws_host = f'wss://{kwargs["region"]}-elb.app.lagerdata.com'
+        else:
+            ws_host = self.ws_host
+        uri = urllib.parse.urljoin(ws_host, path)
 
         headers = [
             (b'authorization', self.session.headers['Authorization'].encode()),
@@ -550,12 +618,15 @@ class CIEnvironment(Enum):
     DRONE = 'drone'
     GITHUB = 'github'
     BITBUCKET = 'bitbucket'
+    GITLAB = 'gitlab'
     GENERIC_CI = 'ci'
+    JENKINS = 'jenkins'
 
 _CONTAINER_CI = set((
     CIEnvironment.DRONE,
     CIEnvironment.GITHUB,
     CIEnvironment.BITBUCKET,
+    CIEnvironment.GITLAB,
 ))
 
 def is_container_ci(ci_env):
@@ -576,6 +647,10 @@ def get_ci_environment():
             return CIEnvironment.GITHUB
         if os.getenv('BITBUCKET_BUILD_NUMBER'):
             return CIEnvironment.BITBUCKET
+        if 'gitlab' in os.getenv('CI_SERVER_NAME', '').lower():
+            return CIEnvironment.GITLAB
+        if 'jenkins' in os.getenv('BUILD_TAG', '').lower():
+            return CIEnvironment.JENKINS
         return CIEnvironment.GENERIC_CI
 
     return CIEnvironment.HOST
