@@ -17,6 +17,8 @@ from ..config import (
     make_config_path,
     get_devenv_config,
     DEVENV_SECTION_NAME,
+    LAGER_CONFIG_FILE_NAME,
+    get_global_config_file_path,
 )
 
 @click.group()
@@ -70,7 +72,8 @@ def create(ctx, image, mount_dir, shell):
 
 @devenv.command()
 @click.pass_context
-def terminal(ctx):
+@click.option('--mount', '-m', help='Name of volume to mount', required=False)
+def terminal(ctx, mount):
     """
         Start an interactive terminal for a docker image
     """
@@ -80,7 +83,7 @@ def terminal(ctx):
     image = section.get('image')
     source_dir = os.path.dirname(path)
     mount_dir = section.get('mount_dir')
-    proc = subprocess.run([
+    args = [
         'docker',
         'run',
         '-it',
@@ -88,10 +91,23 @@ def terminal(ctx):
         '--rm',
         '-w',
         mount_dir,
-        '-v',
-        f'{source_dir}:{mount_dir}',
-        image,
-    ], check=False)
+    ]
+    if mount:
+        args.extend(['--mount', f'source={mount},target={mount_dir}'])
+    else:
+        args.extend(['-v', f'{source_dir}:{mount_dir}'])
+
+    global_config_path = get_global_config_file_path()
+    if os.path.exists(global_config_path):
+        args.extend([
+            '--env=LAGER_CONFIG_FILE_DIR=/lager',
+            '-v',
+            f'{global_config_path}:/lager/{LAGER_CONFIG_FILE_NAME}'
+        ])
+
+    args.append(image)
+
+    proc = subprocess.run(args, check=False)
     ctx.exit(proc.returncode)
 
 
