@@ -17,7 +17,7 @@ from ..config import (
 )
 from ..context import get_ci_environment, CIEnvironment, is_container_ci
 
-def _run_command_host(section, path, cmd_to_run, extra_args, debug):
+def _run_command_host(section, path, cmd_to_run, mount, extra_args, debug, interactive, tty, user, group):
     """
         Run a command from the host (which means, run it in a docker container)
     """
@@ -31,8 +31,21 @@ def _run_command_host(section, path, cmd_to_run, extra_args, debug):
         click.echo(full_command, err=True)
     env_vars = [var for var in os.environ if var.startswith('LAGER')]
     env_strings = [f'--env={var}={os.environ[var]}' for var in env_vars]
-    base_command = ['docker', 'run', '-it', '--rm']
+    base_command = ['docker', 'run', '--rm']
+    if interactive:
+        base_command.append('-i')
+    if tty:
+        base_command.append('-t')
+
     base_command.extend(env_strings)
+    user_group_string = ''
+    if user:
+        user_group_string += user
+    if group:
+        user_group_string += f':{group}'
+
+    if user_group_string:
+        base_command.extend(['-u', user_group_string])
 
     global_config_path = get_global_config_file_path()
     if os.path.exists(global_config_path):
@@ -42,9 +55,18 @@ def _run_command_host(section, path, cmd_to_run, extra_args, debug):
             f'{global_config_path}:/lager/{LAGER_CONFIG_FILE_NAME}'
         ])
 
+    if mount:
+        base_command.extend([
+            '--mount',
+            f'source={mount},target={mount_dir}',
+        ])
+    else:
+        base_command.extend([
+            '-v',
+            f'{source_dir}:{mount_dir}',
+        ])
+
     base_command.extend([
-        '-v',
-        f'{source_dir}:{mount_dir}',
         '-w',
         mount_dir,
         image,
@@ -67,12 +89,12 @@ def _run_command_container(section, cmd_to_run, extra_args, debug):
     proc = subprocess.run([shell, '-c', full_command], check=False)
     return proc.returncode
 
-def _run_command(section, path, cmd_to_run, extra_args, debug):
+def _run_command(section, path, cmd_to_run, mount, extra_args, debug, interactive, tty, user, group):
     ci_env = get_ci_environment()
     if is_container_ci(ci_env):
         return _run_command_container(section, cmd_to_run, extra_args, debug)
-    if ci_env == CIEnvironment.HOST:
-        return _run_command_host(section, path, cmd_to_run, extra_args, debug)
+    if ci_env in (CIEnvironment.HOST, CIEnvironment.JENKINS):
+        return _run_command_host(section, path, cmd_to_run, mount, extra_args, debug, interactive, tty, user, group)
     raise ValueError(f'Unknown CI environment {ci_env}')
 
 
@@ -83,7 +105,12 @@ def _run_command(section, path, cmd_to_run, extra_args, debug):
 @click.option('--command', help='Raw commandline to execute in docker container', metavar='\'<cmdline>\'')
 @click.option('--save-as', default=None, help='Alias under which to save command specified with --command', metavar='<alias>', show_default=True)
 @click.option('--warn/--no-warn', default=True, help='Whether to print a warning if overwriting an existing command.', show_default=True)
-def exec_(ctx, cmd_name, extra_args, command, save_as, warn):
+@click.option('--mount', '-m', help='Name of volume to mount', required=False)
+@click.option('--interactive/--no-interactive', '-i', is_flag=True, help='Keep STDIN open even if not attached', default=True, show_default=True)
+@click.option('--tty/--no-tty', '-t', is_flag=True, help='Allocate a pseudo-TTY', default=True, show_default=True)
+@click.option('--user', '-u', help='User to run as in container', default=None)
+@click.option('--group', '-g', help='Group to run as in container', default=None)
+def exec_(ctx, cmd_name, extra_args, command, save_as, warn, mount, interactive, tty, user, group):
     """
         Execute COMMAND in a docker container. COMMAND is a named command which was previously saved using `--save-as`.
         If COMMAND is not provided, execute the command specified by --command. If --save-as is also provided,
@@ -94,6 +121,18 @@ def exec_(ctx, cmd_name, extra_args, command, save_as, warn):
         click.echo(exec_.get_help(ctx))
         ctx.exit(0)
 
+    if user is None:
+        try:
+            user = str(os.getuid())
+        except AttributeError:
+            pass
+
+    if group is None:
+        try:
+            group = str(os.getgid())
+        except AttributeError:
+            pass
+
     path, config = get_devenv_config()
     section = config[DEVENV_SECTION_NAME]
 
@@ -120,5 +159,5 @@ def exec_(ctx, cmd_name, extra_args, command, save_as, warn):
             add_devenv_command(section, save_as, cmd_to_run, warn)
             write_config_file(config, path)
 
-    returncode = _run_command(section, path, cmd_to_run, extra_args, ctx.obj.debug)
+    returncode = _run_command(section, path, cmd_to_run, mount, extra_args, ctx.obj.debug, interactive, tty, user, group)
     ctx.exit(returncode)
