@@ -129,24 +129,39 @@ class TTYIO:
     """
         Class for doing I/O with a TTY managed by curses
     """
-    def __init__(self, line_ending=b''):
+    def __init__(self, line_ending=b'', opost=False):
         self.stdin_fileno = sys.stdin.fileno()
         self.stdout_fileno = sys.stdout.fileno()
         self.old_settings = termios.tcgetattr(self.stdin_fileno)
         tty.setraw(self.stdin_fileno)
         self.line_ending = line_ending
+        self._opost = opost
 
     def shutdown(self):
         """
             Restore previous TTY settings
         """
+        self.restore()
+
+    def restore(self):
         termios.tcsetattr(self.stdin_fileno, termios.TCSADRAIN, self.old_settings)
 
     def output(self, data, fg=None, flush=False):
         """
             Output some data to the TTY
         """
-        os.write(self.stdout_fileno, data)
+        if self._opost:
+            self.restore()
+            if fg:
+                click.secho(data, nl=False, fg=fg)
+            else:
+                click.echo(data, nl=False)
+            if flush:
+                sys.stdout.flush()
+
+            tty.setraw(self.stdin_fileno)
+        else:
+            os.write(self.stdout_fileno, data)
 
     def read(self):
         """
@@ -199,14 +214,14 @@ class StandardIO:
 
 
 @retry(reraise=True, sleep=trio.sleep, stop=stop_after_attempt(4), wait=wait_fixed(2), retry=retry_if_exception_type(trio_websocket.ConnectionRejected))
-async def display_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, success_regex=None, failure_regex=None):
+async def display_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, success_regex=None, failure_regex=None, opost=False):
     """
         Display job output from websocket
     """
     (uri, kwargs) = connection_params
     match_class = test_matcher_factory(test_runner)
     if interactive:
-        io_source = TTYIO(line_ending)
+        io_source = TTYIO(line_ending, opost)
     else:
         io_source = StandardIO()
     try:
@@ -230,7 +245,7 @@ async def display_job_output(connection_params, test_runner, interactive, line_e
         if io_source:
             io_source.shutdown()
 
-def run_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, debug=False, success_regex=None, failure_regex=None):
+def run_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, debug=False, success_regex=None, failure_regex=None, opost=False):
     """
         Run async task to get job output from websocket
     """
@@ -249,7 +264,7 @@ def run_job_output(connection_params, test_runner, interactive, line_ending, mes
         raise ValueError('Invalid line ending')
 
     try:
-        matcher = trio.run(display_job_output, connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, success_regex, failure_regex)
+        matcher = trio.run(display_job_output, connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout, eof_timeout, success_regex, failure_regex, opost)
         click.get_current_context().exit(matcher.exit_code)
     except trio.TooSlowError:
         suffix = '' if overall_timeout == 1 else 's'
