@@ -64,9 +64,10 @@ def do_uart(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, x
 @click.option('--eof-timeout', default=None, type=click.FLOAT,
               help='Time in seconds to wait before closing connection after input EOF received')
 @click.option('--display-job-id', default=False, is_flag=True)
-@click.option('--line-ending', help='Line ending - select either CRLF (\\r\\n) or LF (\\n)', type=click.Choice(['CRLF', 'LF']), default='LF')
+@click.option('--line-ending', help='Line ending for input - determines the bytes sent to the Device Under Test when you press `Enter` or `Return`', type=click.Choice(['CRLF', 'LF']), default='LF')
+@click.option('--opost/--no-opost', help=r'Enable implementation-defined output processing for your local output terminal. Typically this will convert \n to \r\n on output', is_flag=True, default=False, show_default=True)
 def uart(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, xonxoff, rtscts, dsrdtr,
-         test_runner, interactive, message_timeout, overall_timeout, eof_timeout, display_job_id, line_ending):
+         test_runner, interactive, message_timeout, overall_timeout, eof_timeout, display_job_id, line_ending, opost):
     """
         Connect to UART on a DUT.
     """
@@ -78,6 +79,9 @@ def uart(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, xonx
             click.echo('stdout is not a tty!', err=True)
             ctx.exit(1)
 
+    if gateway is None:
+        gateway = get_default_gateway(ctx)
+
     resp = do_uart(
         ctx, gateway, serial_device, baudrate, bytesize, parity,
         stopbits, xonxoff, rtscts, dsrdtr, test_runner,
@@ -87,6 +91,8 @@ def uart(ctx, gateway, serial_device, baudrate, bytesize, parity, stopbits, xonx
     if display_job_id:
         click.echo('Job id: {}'.format(job_id), err=True)
 
-    connection_params = ctx.obj.websocket_connection_params(socktype='job', job_id=job_id)
+    region = ctx.obj.session.region(gateway)
+
+    connection_params = ctx.obj.websocket_connection_params(socktype='job', job_id=job_id, region=region)
     run_job_output(connection_params, test_runner, interactive, line_ending, message_timeout, overall_timeout,
-        eof_timeout, ctx.obj.debug)
+        eof_timeout, ctx.obj.debug, opost=opost)
