@@ -30,10 +30,11 @@ def status(ctx, gateway):
     session = ctx.obj.session
     resp = session.get_wifi_state(gateway)
     resp.raise_for_status()
-
-    click.echo('State: {}'.format(resp.json().get('state')))
-    click.echo('SSID:  {}'.format(resp.json().get('ssid')))
-
+    wifis = resp.json()
+    for key in wifis:
+        click.echo(f"Interface: {key}")
+        click.echo(f'\tSSID:  {wifis[key]["ssid"]}')
+        click.echo(f'\tState: {wifis[key]["state"]}')
 
 @_wifi.command()
 @click.pass_context
@@ -67,9 +68,9 @@ def access_points(ctx, gateway, interface=None):
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway')
 @click.option('--ssid', required=True, help='SSID of the network to connect to')
+@click.option('--interface', required=True, help='Wireless interface to use')
 @click.option('--password', required=False, help='Password of the network to connect to', default='')
-@click.option('--interface', required=False, help='Wireless interface to use')
-def connect(ctx, gateway, ssid, password='', interface=None):
+def connect(ctx, gateway, ssid, interface, password=''):
     """
         Connect the gateway to a new network
     """
@@ -80,15 +81,15 @@ def connect(ctx, gateway, ssid, password='', interface=None):
     resp = session.connect_wifi(gateway, ssid, password, interface)
     resp.raise_for_status()
     if resp.json().get('acknowledged'):
-        click.echo('Acknowledged', nl=False)
+        click.secho(f'{interface} connected', fg='green')
 
 
 @_wifi.command()
 @click.pass_context
 @click.option('--gateway', required=False, help='ID of gateway')
+@click.option('--interface', required=True, help='Wireless interface to use')
 @click.option('--ssid', required=False, help='SSID of the network to delete')
-@click.option('--interface', required=False, help='Wireless interface to use')
-def delete_connection(ctx, gateway, ssid=None, interface=None):
+def delete_connection(ctx, gateway, interface, ssid=None):
     """
         Delete the specified network from the gateway
     """
@@ -99,4 +100,4 @@ def delete_connection(ctx, gateway, ssid=None, interface=None):
     resp = session.delete_wifi_connection(gateway, ssid, interface)
     resp.raise_for_status()
     if resp.json().get('acknowledged'):
-        click.echo('Acknowledged', nl=False)
+        click.secho(f'{interface} disconnected', fg='green')
